# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_publish_metric_input import ServicePublishMetricInput

class TestServicePublishMetricInput(unittest.TestCase):
    """ServicePublishMetricInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicePublishMetricInput:
        """Test ServicePublishMetricInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServicePublishMetricInput`
        """
        model = ServicePublishMetricInput()
        if include_optional:
            return ServicePublishMetricInput(
                decr = nuon.models.metrics/decr.metrics.Decr(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, ),
                event = nuon.models.metrics/event.metrics.Event(
                    event = nuon.models.statsd/event.statsd.Event(
                        aggregation_key = '', 
                        alert_type = null, 
                        hostname = '', 
                        priority = null, 
                        source_type_name = '', 
                        tags = [
                            ''
                            ], 
                        text = '', 
                        timestamp = '', 
                        title = '', ), ),
                incr = nuon.models.metrics/incr.metrics.Incr(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, ),
                timing = nuon.models.metrics/timing.metrics.Timing(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, )
            )
        else:
            return ServicePublishMetricInput(
        )
        """

    def testServicePublishMetricInput(self):
        """Test ServicePublishMetricInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_install_component import AppInstallComponent

class TestAppInstallComponent(unittest.TestCase):
    """AppInstallComponent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstallComponent:
        """Test AppInstallComponent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstallComponent`
        """
        model = AppInstallComponent()
        if include_optional:
            return AppInstallComponent(
                component = nuon.models.app/component.app.Component(
                    app_id = '', 
                    config_versions = 56, 
                    created_at = '', 
                    created_by_id = '', 
                    dependencies = [
                        ''
                        ], 
                    id = '', 
                    name = '', 
                    status = '', 
                    status_description = '', 
                    updated_at = '', ),
                component_id = '',
                created_at = '',
                created_by_id = '',
                id = '',
                install_deploys = [
                    nuon.models.app/install_deploy.app.InstallDeploy(
                        build_id = '', 
                        component_id = '', 
                        component_name = '', 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_component_id = '', 
                        install_deploy_type = 'release', 
                        install_id = '', 
                        release_id = '', 
                        status = '', 
                        status_description = '', 
                        updated_at = '', )
                    ],
                install_id = '',
                updated_at = ''
            )
        else:
            return AppInstallComponent(
        )
        """

    def testAppInstallComponent(self):
        """Test AppInstallComponent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.51
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json




from pydantic import BaseModel, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from nuon.models.service_connected_github_vcs_config_request import ServiceConnectedGithubVCSConfigRequest
from nuon.models.service_public_git_vcs_config_request import ServicePublicGitVCSConfigRequest
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ServiceCreateHelmComponentConfigRequest(BaseModel):
    """
    ServiceCreateHelmComponentConfigRequest
    """ # noqa: E501
    chart_name: StrictStr
    connected_github_vcs_config: Optional[ServiceConnectedGithubVCSConfigRequest] = None
    public_git_vcs_config: Optional[ServicePublicGitVCSConfigRequest] = None
    values: Dict[str, StrictStr]
    __properties: ClassVar[List[str]] = ["chart_name", "connected_github_vcs_config", "public_git_vcs_config", "values"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ServiceCreateHelmComponentConfigRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connected_github_vcs_config
        if self.connected_github_vcs_config:
            _dict['connected_github_vcs_config'] = self.connected_github_vcs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of public_git_vcs_config
        if self.public_git_vcs_config:
            _dict['public_git_vcs_config'] = self.public_git_vcs_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ServiceCreateHelmComponentConfigRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "chart_name": obj.get("chart_name"),
            "connected_github_vcs_config": ServiceConnectedGithubVCSConfigRequest.from_dict(obj.get("connected_github_vcs_config")) if obj.get("connected_github_vcs_config") is not None else None,
            "public_git_vcs_config": ServicePublicGitVCSConfigRequest.from_dict(obj.get("public_git_vcs_config")) if obj.get("public_git_vcs_config") is not None else None,
            "values": obj.get("values")
        })
        return _obj





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.51
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class AppAppRunnerType(str, Enum):
    """
    AppAppRunnerType
    """

    """
    allowed enum values
    """
    AWS_MINUS_ECS = 'aws-ecs'
    AWS_MINUS_EKS = 'aws-eks'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AppAppRunnerType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_app_installer import ServiceAppInstaller

class TestServiceAppInstaller(unittest.TestCase):
    """ServiceAppInstaller unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceAppInstaller:
        """Test ServiceAppInstaller
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceAppInstaller`
        """
        model = ServiceAppInstaller()
        if include_optional:
            return ServiceAppInstaller(
                app = nuon.models.app/app.app.App(
                    created_at = '', 
                    created_by_id = '', 
                    id = '', 
                    name = '', 
                    org_id = '', 
                    status = '', 
                    status_description = '', 
                    updated_at = '', ),
                metadata = nuon.models.app/app_installer_metadata.app.AppInstallerMetadata(
                    app_installer_id = '', 
                    community_url = '', 
                    created_at = '', 
                    created_by_id = '', 
                    demo_url = '', 
                    description = '', 
                    documentation_url = '', 
                    github_url = '', 
                    homepage_url = '', 
                    id = '', 
                    logo_url = '', 
                    name = '', 
                    updated_at = '', ),
                sandbox_mode = True
            )
        else:
            return ServiceAppInstaller(
        )
        """

    def testServiceAppInstaller(self):
        """Test ServiceAppInstaller"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
